This function generate the JDOQL query string according to the filters specified by users. The JDOQL query is an essential part of the search URL.
WBjdoql(object = "encounter", location = NULL, locationID = NULL,
sighting_date = c("1964-01-01", "2016-12-31"),
encounter_submission_dates = c("2003-01-01", "2016-12-31"),
date_format = "%Y-%m-%d", sex = c("male", "female", "unknown"),
status = c("alive", "dead"), measurement = NULL, individualID = NULL,
encounterID = NULL, encounter_type = NULL, Date_of_birth = NULL,
Date_of_death = NULL)can be either "encounter" for the encounter search or "individual" for the individual search.
A string of character contained in location names.
A character vector for filtering the locationID.
A character for filtering encounters which are sighted during a period of time.
A character for filtering encounters which are submitted during a period of time.
The format for all the arguments of date valule.
A character vector of maximum size of three represents the value for the sex filter.
A character vector of maximum size of two represents the value for the encounter status.
A numeric object sets the minimum individual measurement when searching in the Wildbook framework.
A character vector for searching data of specific individual ID.
A character vector for searching data of specific encounter ID.
A character vector of maximum size of three for searching data with specific encounter type.
A character vector for searching data of individual which is borned during a period of time.
A character vector for searching data of individual which is dead during a period of time.